@@ -1494,6 +1494,7 @@ inline void xsurface_drawclear_yuv(liqimage *surface,unsigned char grey,unsigned
 //########################################################################
 
 
+
 inline void xsurface_drawfadeoutrect_yuv(liqimage *surface,int x,int y,int w,int h, unsigned char grey,unsigned char u,unsigned char v,unsigned char spread)
 {
 	if(x+w<0)return;
@@ -1510,7 +1511,7 @@ inline void xsurface_drawfadeoutrect_yuv(liqimage *surface,int x,int y,int w,int
 	if(y+h>=surface->height)
 	{
 		if(y>=surface->height) return;
-		h=(surface->height-y);
+		h=(surface->height-y)-1;
 	}
     
 //unsigned char spreaddiv2 = spread/2;
@@ -1541,7 +1542,7 @@ inline void xsurface_drawfadeoutrect_yuv(liqimage *surface,int x,int y,int w,int
 			//*pdata++ = (unsigned char)grey;
             //*pdata++ = y + (((((int)*pdata) * 255) / spread)-spreaddiv2);
 			{
-				int s=y;
+				int s=grey;
 				int t=*pdata;
 				//if(!s)s=128;
 				//if(!t)t=128;
@@ -1562,6 +1563,7 @@ inline void xsurface_drawfadeoutrect_yuv(liqimage *surface,int x,int y,int w,int
 
 	}
 
+
 	y>>=1;
 	x>>=1;
 	w>>=1;
