@@ -373,11 +373,15 @@ int b=(y+h)-1;
 	if(b>self->ey)b=self->ey;
 	if(r&1)r++;
 	if(b&1)b++;
+    
+    //xsurface_drawrect_grey(self->surface,x,y,w,h,grey);
 
 	int tw=(r-x)/16;
 	int th=(b-y)/16;
 	int u;
 	int v;
+    while((tw*16)<w)tw++;
+    while((th*16)<h)th++;
 	//xsurface_drawrect_yuv(self->surface,x,y,(r-x)+1,(b-y)+1,grey,u,v);
 	for(v=1;v<255;v+=16)
 	{
@@ -391,6 +395,50 @@ int b=(y+h)-1;
 	}
 }
 
+void liqcliprect_drawgreycol(liqcliprect *self,int x,int y,int w,int h)
+{
+	//if(w<=0)return;
+	//if(h<=0)return;
+	if(w<0){ x+=w;w=-w;}
+	if(h<0){ y+=h;h=-h;}
+int r=(x+w)-1;
+int b=(y+h)-1;
+
+	if(x<self->sx)x=self->sx;
+	if(y<self->sy)y=self->sy;
+	if(r>self->ex)r=self->ex;
+	if(b>self->ey)b=self->ey;
+	if(r&1)r++;
+	if(b&1)b++;
+    
+    
+    
+    
+    
+
+	int tw=(r-x)/16;
+	int th=(b-y)/16;
+    while((tw*16)<w)tw++;
+    while((th*16)<h)th++;
+    
+    int gg;
+    
+	//xsurface_drawrect_yuv(self->surface,x,y,(r-x)+1,(b-y)+1,grey,u,v);
+    for(gg=0;gg<=255;gg+=16)
+	//for(v=1;v<255;v+=16)
+	{
+        xsurface_drawrect_yuv(self->surface,x,y,w,th+1,gg,128,128);
+        
+		//int xx=x;
+		//for(u=1;u<255;u+=16)
+		//{
+		//	xsurface_drawrect_yuv(self->surface,xx,y,tw+1,th+1,grey,u,v);
+		//	xx+=tw;
+		//}
+		y+=th;
+	}
+
+}
 
 
 
@@ -817,6 +865,8 @@ void liqcliprect_drawsketch(liqcliprect *self,liqsketch *page,int l,int t,int w,
 	// Sun Aug 23 12:41:07 2009 lcuk : fuckit, try full res always and see
 	if(liqapp_hardware_product_ispowerful_get())
 		rpt=1;
+
+	rpt=0;
 	
 
 	switch(page->backgroundstyle)
@@ -1208,7 +1258,7 @@ inline void liqcliprect_drawimagecolor(		liqcliprect *self,liqimage *image,int x
 	if(!w || !h) return;
 	if(w<0){ x+=w;w=-w;}
 	if(h<0){ y+=h;h=-h;}
-	//liqapp_log("drawimg d(%i,%i)-step(%i,%i)  i(%i,%i)-step(%i,%i)  ",x,y,w,h,    0,0,image->width,image->height);
+	//liqapp_log("drawimg d(%i,%i)-step(%i,%i)  i(%i,%i)-step(%i,%i)  ",x,y,w,h,    0,0,image->width,image->height,aspectlock);
 
 	if(aspectlock)
 	{
@@ -1263,7 +1313,7 @@ int b=(y+h);
 		{
 			// he here clipped from the top
 			iy = image->height * (cr.sy-y)/h;
-            iy--;
+            ih--;
 		}
 	}
 
@@ -1281,7 +1331,7 @@ int b=(y+h);
 
 
 
-	//liqapp_log("dxy %i,%i dwh %i,%i    iwh %i,%i",dx,dy,dw,dh,  image->width-1,image->height-1);
+	//liqapp_log("dxy %i,%i dwh %i,%i    iwh %i,%i  cr(%i,%i wh %i,%i)",dx,dy,dw,dh,  image->width-1,image->height-1,cr.sx,cr.sy,cw,ch);
 
 	if(w==0||h==0)return;
 	xsurface_drawzoomimage( image,
@@ -1369,7 +1419,7 @@ int b=(y+h);
 		{
 			// he here clipped from the top
 			iy = image->height * (cr.sy-y)/h;
-            iy--;
+            ih--;
 		}
 	}
 
